<?php

App::import('AppController', 'Controller');

class DistrictsController extends AppController {

    public $name = 'Districts';
    public $uses = array('District', 'Country', 'Region','Territory');
    public $helper = array('Html', 'Session', 'Paginator');
    public $components = array('Session', 'Paginator', 'Flash','CommonCmp');
    public $paginate = array('limit' => 20, 'order' => array('District.district_code' => 'asc'));
    public $user_id = '';
    public $logintype = '';

    public function beforeFilter() {
        parent::beforeFilter();
        $this->logintype = $this->Session->read('logintype');
    }

    public function managedistricts() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        }else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Manage District');
            $conditions = array();
            $searchkey = '';
            if (isset($this->request->data['District']['searchkey']) && ($this->request->data['District']['searchkey'] != '')) {
                $searchkey = trim($this->request->data['District']['searchkey']);
                $conditions['OR'] = array(
                    'District.region_id LIKE' => "%$searchkey%",
                    'District.district_code LIKE' => "%$searchkey%",
                    'District.district_name LIKE' => "%$searchkey%"
                );
            }

            $this->paginate['conditions'] = $conditions;
            $this->set('searchkey', $searchkey);

            $this->Paginator->settings = $this->paginate;
            $data = $this->Paginator->paginate('District');
            $this->set('data', $data);
        }
    }

    public function addDistrict() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        }else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Add District');
            $zoneList = $this->CommonCmp->commonList('Zone',array('Zone.status'=>'true'),array('Zone.zone_code','Zone.zone_code'),array('Zone.zone_code'=>'ASC'),'list');            
            $this->set('zoneList',$zoneList);
        }
    }

    public function editDistrict() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        }else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Update District');
            $rid = $this->request->query('id');
            if (!empty($rid) && ($rid != '')) {
                $this->District->id = $rid;
                $this->request->data = $this->District->read();                 
                $regiondata = $this->CommonCmp->commonList('Region',array('Region.region_code'=>$this->request->data['District']['region_id']),array('Region.zone_id'),array(),'first');
                
                $zoneSelected = $regiondata['Region']['zone_id'];
                $regionSelected = $this->request->data['District']['region_id'];
                
                $zoneList = $this->CommonCmp->commonList('Zone',array('Zone.status'=>'true'),array('Zone.zone_code','Zone.zone_code'),array('Zone.zone_code'=>'ASC'),'list');
            
            $this->set('zoneList',$zoneList);
                $this->set('zoneSelected',$zoneSelected);
                $this->set('regionSelected',$regionSelected);
            } else {
                $this->redirect('managedistricts');
            }
        }
    }

    public function saveDistrict() {
        if (!empty($this->request->data)) {
            $conditions = array(
                'district_code' => $this->request->data['District']['district_code']
            );
            $msg = 'District added successfully.';
            if (isset($this->request->data['District']['id']) && ($this->request->data['District']['id'] != '')) {
                $conditions['id !='] = $this->request->data['District']['id'];
                $msg = 'District updated successfully.';
            }
            $checkexist = $this->District->find('count', array(
                'conditions' => $conditions
            ));
            if ($checkexist <= 0) {
                $this->District->create();
                if ($this->District->save($this->request->data)) {
                    $this->Flash->success($msg);
                    $this->redirect('managedistricts');
                } else {
                    $this->Session->warning('Please fill all fields.');
                    $this->redirect('managedistricts');
                }
            } else {
                $this->Flash->warning('District already exists.');
                $this->redirect('managedistricts');
            }
        }
    }

    public function groupaction() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        }else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $querydata = $this->request->query;
            $statusArr = $this->CommonCmp->groupActions('District', $querydata);         
            $status = isset($statusArr['status'])?$statusArr['status']:'error';
            $msg = isset($statusArr['msg'])?$statusArr['msg']:'Technical error please try after sometime.';
            $this->Flash->$status($msg);
            $this->redirect($this->referer());
        }
    }
    
    public function loadregionlist() {
        $this->layout = false;
        $this->autoRender = false;
        $listData = array();
        if ($this->request->is('ajax') && isset($this->request->data['zone_id']) && $this->request->data['zone_id'] != '') {
            $listData = $this->CommonCmp->commonList('Region', array('status' => 'true', 'zone_id' => $this->request->data['zone_id']), array('Region.region_code', 'Region.region_name'), array('region_name' => 'asc'), $type = 'list');
        }
        echo json_encode($listData);
        exit();
    }
    
}
