<?php

App::import('AppController', 'Controller');
App::import('Vendor', 'PHPExcel', array('file' => 'PHPExcel/Classes/PHPExcel.php'));

class PincodesController extends AppController {

    public $name = 'Pincodes';
    public $uses = array('Pincode', 'Country','Territory','Dealer');
    public $helper = array('Html', 'Session', 'Paginator');
    public $components = array('Session', 'Paginator', 'Flash', 'CommonCmp');
    public $paginate = array('limit' => 20, 'order' => array('Pincode.pincode_code' => 'asc'));
    public $user_id = '';
    public $logintype = '';
    public $sheetCols = array();

    public function beforeFilter() {
        parent::beforeFilter();
        $this->logintype = $this->Session->read('logintype');
        $this->sheetCols = array('Pincode Code', 'Pincode Latlong', 'Pincode Population', 'District Id', 'Pincode House Hold');
    }

    public function importpincode() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Import Pincodes');
        }
    }

    public function managepincodes() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else {
            $this->set('title_for_layout', 'Administrator || Manage Pincode');
            $conditions = array();
            $searchkey = '';
            if (isset($this->request->data['Pincode']['searchkey']) && ($this->request->data['Pincode']['searchkey'] != '')) {
                $searchkey = trim($this->request->data['Pincode']['searchkey']);
                $conditions['OR'] = array(
                    'Pincode.district_id LIKE' => "%$searchkey%",
                    'Pincode.pincode_code LIKE' => "%$searchkey%"
                );
            }

            $this->paginate['conditions'] = $conditions;
            $this->set('searchkey', $searchkey);

            $this->Paginator->settings = $this->paginate;
            $data = $this->Paginator->paginate('Pincode');
            $this->set('data', $data);
        }
    }

    public function addPincode() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else {
            $this->set('title_for_layout', 'Administrator || Add Pincode');
        }
        
        $districtList = $this->CommonCmp->commonList('District',array('District.status'=>'true'),array('District.district_code','District.district_name'),array('District.district_name'=>'ASC'),'list');
        $this->set('districtList',$districtList);
    }

    public function editPincode() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else {
            $this->set('title_for_layout', 'Administrator || Update Pincode');
            $rid = $this->request->query('id');
            if (!empty($rid) && ($rid != '')) {
                $this->Pincode->id = $rid;
                $this->request->data = $this->Pincode->read();
            } else {
                $this->redirect('managepincodes');
            }
            $districtList = $this->CommonCmp->commonList('District',array('District.status'=>'true'),array('District.district_code','District.district_name'),array('District.district_name'=>'ASC'),'list');
        $this->set('districtList',$districtList);
        }
    }

    public function savePincode() {
        if (!empty($this->request->data)) {
            $conditions = array(
                'Pincode.pincode_code' => $this->request->data['Pincode']['pincode_code']
            );
            $msg = 'Pincode added successfully.';
            if (isset($this->request->data['Pincode']['id']) && ($this->request->data['Pincode']['id'] != '')) {
                $conditions['id !='] = $this->request->data['Pincode']['id'];
                $msg = 'Pincode updated successfully.';
            }
            $checkexist = $this->Pincode->find('count', array(
                'conditions' => $conditions
            ));
            if ($checkexist <= 0) {
                $this->Pincode->create();
                if ($this->Pincode->save($this->request->data)) {
                    $this->Flash->success($msg);
                    $this->redirect('managepincodes');
                } else {
                    $this->Flash->warning('Please fill all fields.');
                    $this->redirect('managepincodes');
                }
            } else {
                $this->Flash->warning('Pincode already exists.');
                $this->redirect('managepincodes');
            }
        }
    }

    public function groupaction() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else {
            $querydata = $this->request->query;
            $statusArr = $this->CommonCmp->groupActions('Pincode', $querydata);
            $status = isset($statusArr['status']) ? $statusArr['status'] : 'error';
            $msg = isset($statusArr['msg']) ? $statusArr['msg'] : 'Technical error please try after sometime.';
            $this->Flash->$status($msg);
            $this->redirect($this->referer());
        }
    }

    public function processfile() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
        $objPHPExcel = new PHPExcel();
        if (isset($this->request->data['Pincode']['filename']["name"]) && ($this->request->data['Pincode']['filename']["name"] != '')) {
            $upload_dir = FILE_UPLOAD_PATH;
            $original = explode('.', $this->request->data['Pincode']['filename']["name"]);
            $extension = array_pop($original);
            $newname = date('YmdHis') . '.' . $extension;
            if (file_exists($upload_dir . $newname)) {
                unlink($upload_dir . $newname);
            }
            if (move_uploaded_file($this->request->data['Pincode']['filename']["tmp_name"], $upload_dir . $newname)) {
                $insertData['Pincode'] = array();
                $updateData['Pincode'] = array();
                $object = PHPExcel_IOFactory::load($upload_dir . $newname);
                foreach ($object->getWorksheetIterator() as $worksheet) {
                    $highestRow = $worksheet->getHighestRow();
                    $highestColumn = $worksheet->getHighestColumn();

                    if (!$this->validateSheetCols($worksheet, 1)) {
                        $invaliCols = implode(',', $this->Session->read('invaliCols'));
                        $this->Flash->notice('Invalid column(s) ' . $invaliCols);
                        $this->redirect('importpincode');
                    }
                    for ($row = 2; $row <= $highestRow; $row++) {
                        $dataSet = $this->excelToArray($worksheet, $row);

                        $pincode_code = $dataSet['pincode_code'];
                        $conditions = array(
                            'Pincode.pincode_code' => $pincode_code
                        );
                        $existing = $this->checkExist(array('id', 'pincode_code', 'district_id', 'prosperity_index', 'pincode_house_hold', 'status'), $conditions);

                        if ($existing) {
                            $dataSet['district_id'] = $existing['Pincode']['district_id'];
                            $dataSet['prosperity_index'] = $existing['Pincode']['prosperity_index'];
                            $dataSet['pincode_house_hold'] = $existing['Pincode']['pincode_house_hold'];
                            $dataSet['status'] = $existing['Pincode']['status'];
                            $dataSet['id'] = $existing['Pincode']['id'];
                            $updateData['Pincode'][] = $dataSet;
                        } else {
                            $dataSet['status'] = true;
                            $insertData['Pincode'][] = $dataSet;
                        }
                    }
                }

                $addedRecords = 0;
                $updatedRecords = 0;
                if (count($insertData['Pincode']) > 0) {
                    $addedRecords = count($insertData['Pincode']);
                    $this->Pincode->saveAll($insertData['Pincode']);
                }

                if (count($updateData['Pincode']) > 0) {
                    $updatedRecords = count($updateData['Pincode']);
                    $this->Pincode->saveAll($updateData['Pincode']);
                }

                $this->Flash->success($addedRecords . ' record(s) added & ' . $updatedRecords . ' record(s) updated.');
            }else{
              $this->Flash->warning('Upload file directory is not writable');  
            }
        } else {
            $this->Flash->error('Please select file.');
        }
    }
        $this->redirect('importpincode');
    }

    private function checkExist($fields, $conditions) {

        return $this->Pincode->find('first', array('fields' => $fields, 'conditions' => $conditions));
    }

    private function excelToArray($worksheet, $row) {
        $pincode_code = $this->removeSpaces($worksheet->getCellByColumnAndRow(0, $row)->getValue());
        $pincode_latlong = $this->removeSpaces($worksheet->getCellByColumnAndRow(1, $row)->getValue());
        $pincode_population = $this->removeSpaces($worksheet->getCellByColumnAndRow(2, $row)->getValue());

        $district_id = '';
        if ($worksheet->getCellByColumnAndRow(3, $row)->getValue() !='') {
            $district_id = $this->removeSpaces($worksheet->getCellByColumnAndRow(3, $row)->getValue());
        }
        $prosperity_index = '';
        if ($worksheet->getCellByColumnAndRow(4, $row)->getValue() !='') {
            $prosperity_index = $this->removeSpaces($worksheet->getCellByColumnAndRow(4, $row)->getValue());
        }
        $pincode_house_hold = '';
        if ($worksheet->getCellByColumnAndRow(5, $row)->getValue() !='') {
            $pincode_house_hold = $this->removeSpaces($worksheet->getCellByColumnAndRow(5, $row)->getValue());
        }
        $data = array(
            'pincode_code' => $pincode_code,
            'pincode_latlong' => $pincode_latlong,
            'pincode_population' => $pincode_population,
            'district_id' => $district_id,
            'prosperity_index' => $prosperity_index,
            'pincode_house_hold' => $pincode_house_hold
        );
        return $data;
    }
    
    private function validateSheetCols($worksheet, $row) {
        $isValid = true;
        $invaliCols = array();
        foreach ($this->sheetCols as $key => $defineColName) {
            $sheetColName = $worksheet->getCellByColumnAndRow($key, $row)->getValue();
            if ($this->removeSpaces($defineColName) != $this->removeSpaces($sheetColName)) {
                $invaliCols[] = $sheetColName;
            }
        }
        if (count($invaliCols) > 0) {
            $this->Session->write('invaliCols', $invaliCols);
            $isValid = false;
        }
        return $isValid;
    }

    private function removeSpaces($string) {
        return strtolower(preg_replace('/\s+/', '', $string));
    }

}
