<?php

App::import('AppController', 'Controller');

class RegionsController extends AppController {

    public $name = 'Regions';
    public $uses = array('Region', 'Country', 'Zone','Territory');
    public $helper = array('Html', 'Session', 'Paginator');
    public $components = array('Session', 'Paginator', 'Flash','CommonCmp');
    public $paginate = array('limit' => 20, 'order' => array('Region.region_code' => 'asc'));
    public $user_id = '';
    public $logintype = '';

    public function beforeFilter() {
        parent::beforeFilter();
        $this->logintype = $this->Session->read('logintype');
    }

    public function manageregions() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        }else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Manage Region');
            $conditions = array();
            $searchkey = '';
            if (isset($this->request->data['Region']['searchkey']) && ($this->request->data['Region']['searchkey'] != '')) {
                $searchkey = trim($this->request->data['Region']['searchkey']);
                $conditions['OR'] = array(
                    'Region.zone_id LIKE' => "%$searchkey%",
                    'Region.region_code LIKE' => "%$searchkey%",
                    'Region.region_name LIKE' => "%$searchkey%"
                );
            }

            $this->paginate['conditions'] = $conditions;
            $this->set('searchkey', $searchkey);

            $this->Paginator->settings = $this->paginate;
            $data = $this->Paginator->paginate('Region');
            $this->set('data', $data);
        }
    }

    public function addRegion() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        }else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Add Region');
            $zoneList = $this->CommonCmp->commonList('Zone',array('Zone.status'=>'true'),array('Zone.zone_code','Zone.zone_code'),array('Zone.zone_code'=>'ASC'),'list');
            
            $this->set('zoneList',$zoneList);
        }
    }

    public function editRegion() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        }else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Update Region');
            $rid = $this->request->query('id');
            if (!empty($rid) && ($rid != '')) {
                $this->Region->id = $rid;
                $this->request->data = $this->Region->read();
            } else {
                $this->redirect('manageregions');
            }
            $zoneList = $this->CommonCmp->commonList('Zone',array('Zone.status'=>'true'),array('Zone.zone_code','Zone.zone_code'),array('Zone.zone_code'=>'ASC'),'list');
            
            $this->set('zoneList',$zoneList);
        }
    }

    public function saveRegion() {
        if (!empty($this->request->data)) {
            $conditions = array(
                'region_code' => $this->request->data['Region']['region_code']
            );
            $msg = 'Region added successfully.';
            if (isset($this->request->data['Region']['id']) && ($this->request->data['Region']['id'] != '')) {
                $conditions['id !='] = $this->request->data['Region']['id'];
                $msg = 'Region updated successfully.';
            }
            $checkexist = $this->Region->find('count', array(
                'conditions' => $conditions
            ));
            if ($checkexist <= 0) {
                $this->Region->create();
                if ($this->Region->save($this->request->data)) {
                    $this->Flash->success($msg);
                    $this->redirect('manageregions');
                } else {
                    $this->Session->warning('Please fill all fields.');
                    $this->redirect('manageregions');
                }
            } else {
                $this->Flash->warning('Region already exists.');
                $this->redirect('manageregions');
            }
        }
    }

    public function groupaction() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        }else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $querydata = $this->request->query;
            $statusArr = $this->CommonCmp->groupActions('Region', $querydata);         
            $status = isset($statusArr['status'])?$statusArr['status']:'error';
            $msg = isset($statusArr['msg'])?$statusArr['msg']:'Technical error please try after sometime.';
            $this->Flash->$status($msg);
            $this->redirect($this->referer());
        }
    }
}
