<?php

App::import('AppController', 'Controller');

class TerritoriesController extends AppController {

    public $name = 'Territories';
    public $uses = array('Territory', 'Area', 'Pincode');
    public $helper = array('Html', 'Session', 'Paginator','Common');
    public $components = array('Session', 'Paginator', 'Flash', 'CommonCmp');
    public $paginate = array('limit' => 20, 'order' => array('Territory.territory_code' => 'asc'));
    public $user_id = '';
    public $logintype = '';

    public function beforeFilter() {
        parent::beforeFilter();
        $this->logintype = $this->Session->read('logintype');
    }

    public function manageterritory() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else {
            $this->set('title_for_layout', 'Administrator || Manage Territory');
            $conditions = array();
            $searchkey = '';
            if (isset($this->request->data['Territory']['searchkey']) && ($this->request->data['Territory']['searchkey'] != '')) {
                $searchkey = trim($this->request->data['Territory']['searchkey']);
                
                $conditions['OR'] = array(
                    'Territory.district_id LIKE' => "%$searchkey%",
                    'Territory.territory_code LIKE' => "%$searchkey%",
                    'Territory.area_id LIKE' => "%$searchkey%"
                );
            }
            $this->paginate['conditions'] = $conditions;
            $this->set('searchkey', $searchkey);
            $this->Paginator->settings = $this->paginate;
            $data = $this->Paginator->paginate('Territory');
            $this->set('data', $data);
        }
    }
    public function addTerritory() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        }else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Add Area');
            $districtList = $this->CommonCmp->commonList('District',array('District.status'=>'true'),array('District.district_code','District.district_name'),array('District.district_name'=>'ASC'),'list');
            $this->set('districtList',$districtList);
        }
    }

    public function editTerritory() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        }else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Update Territory');
            $rid = $this->request->query('id');
            if (!empty($rid) && ($rid != '')) {
                $this->Territory->id = $rid;
                $this->request->data = $this->Territory->read();
                
                $districtList = $this->CommonCmp->commonList('District',array('District.status'=>'true'),array('District.district_code','District.district_name'),array('District.district_name'=>'ASC'),'list');
            $this->set('districtList',$districtList);
            
            
            $cityRuralList = $this->CommonCmp->commonList('Area',array('Area.status'=>'true','Area.district_id'=>$this->request->data['Territory']['district_id']),array('Area.code','Area.name'),array('Area.name'=>'ASC'),'list');
            $this->set('cityRuralList',$cityRuralList);
            
                $pincodeList = $this->CommonCmp->commonList('Pincode',array('Pincode.district_id'=>$this->request->data['Territory']['district_id']),array('Pincode.pincode_code','Pincode.pincode_code'),array('Pincode.pincode_code'=>'ASC'),'list');
            $this->set('pincodeList',$pincodeList);
            
            } else {
                $this->redirect('manageterritory');
            }
        }
    }

    public function saveTerritory() {        
        if (!empty($this->request->data)) {
            $conditions = array(
                'Territory.territory_code' => $this->request->data['Territory']['territory_code']
            );
            $msg = 'Territory added successfully.';
            if (isset($this->request->data['Territory']['id']) && ($this->request->data['Territory']['id'] != '')) {
                $conditions['Territory.id !='] = $this->request->data['Territory']['id'];
                $msg = 'Territory updated successfully.';
            }
            $territory_id = '';
            if (isset($this->request->data['Territory']['id']) && ($this->request->data['Territory']['id'] != '')) {
                $territory_id = $this->request->data['Territory']['id'];
            }
            $pincodes = $this->request->data['Territory']['pincode_code'];
            unset($this->request->data['Territory']['pincode_code']);
            
            if (isset($this->request->data['Territory']['hidden_pincode'])) {
                unset($this->request->data['Territory']['hidden_pincode']);
            }
               
            if (isset($this->request->data['Territory']['hidden_city_rural_id'])) {
                unset($this->request->data['Territory']['hidden_city_rural_id']);
            }

            $this->Territory->create();            
            if ($this->Territory->save($this->request->data)) {
               if ($territory_id =='') {
                 $territory_id = $this->Territory->getLastInsertID();  
               }
               
               if (isset($this->request->data['Territory']['id']) && ($this->request->data['Territory']['id'] != '')) {
                   
                $pincodeList = $this->CommonCmp->commonList('Pincode',array('Pincode.territory_id'=>$this->request->data['Territory']['id']),array('Pincode.pincode_code','Pincode.pincode_code'),array('Pincode.pincode_code'=>'ASC'),'list');
                 $this->Pincode->updateAll(array('Pincode.territory_id' =>"''"),array('Pincode.pincode_code' => array_values($pincodeList)));
               }
               
                $this->Pincode->updateAll(array('Pincode.territory_id' =>"'".$territory_id."'"),array('Pincode.pincode_code' => $pincodes));
                //$this->Pincode->updateAll(array('Pincode.city_rural_id' =>"'".$city_rural_id."'"),array('Pincode.pincode_code' => $pincodes)); 
                    $this->Flash->success($msg);
                    $this->redirect('manageterritory');
                } else {
                    $this->Session->warning('Please fill all fields.');
                    $this->redirect('manageterritory');
                }
        }
    }
    
    public function groupaction() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else {
            $querydata = $this->request->query;
            $statusArr = $this->CommonCmp->groupActions('Territory', $querydata);
            $status = isset($statusArr['status']) ? $statusArr['status'] : 'error';
            $msg = isset($statusArr['msg']) ? $statusArr['msg'] : 'Technical error please try after sometime.';
            $this->Flash->$status($msg);
            $this->redirect($this->referer());
        }
    }
    
    public function loadpincodelist() {
        $this->layout = false;
        $this->autoRender = false;
        $listData = array();
        if ($this->request->is('ajax') && isset($this->request->data['district_id']) && $this->request->data['district_id'] != '') {
            
            $conditions = array();
            
            if (isset($this->request->data['district_id']) && count($this->request->data['district_id']) > 0) {
                $conditions['district_id'] = $this->request->data['district_id'];
            }
            
            /*if (isset($this->request->data['city_rural_id']) && count($this->request->data['city_rural_id']) > 0) {
                $conditions['city_rural_id'] = $this->request->data['city_rural_id'];
            }*/
            $listData = $this->CommonCmp->commonList('Pincode', $conditions, array('Pincode.pincode_code', 'Pincode.pincode_code'), array('Pincode.pincode_code' => 'asc'), $type = 'list');
        }
        echo json_encode($listData);
        exit();
    }
    
    public function loadcityrural() {
        $this->layout = false;
        $this->autoRender = false;
        $listData = array();
        if ($this->request->is('ajax') && isset($this->request->data['district_id']) && $this->request->data['district_id'] != '') {
            $listData = $this->CommonCmp->commonList('Area', array('district_id' => $this->request->data['district_id']), array('Area.code', 'Area.name'), array('Area.code' => 'asc'), $type = 'list');
        }
        echo json_encode($listData);
        exit();
    }
}
