<?php

App::uses('AppController', 'Controller');

class UsersController extends AppController {

    public $uses = array('User', 'Area', 'Zone', 'Territory');
    public $helper = array('Html', 'Session', 'Paginator');
    public $components = array('Session', 'Flash', 'Cookie', 'Paginator', 'CommonCmp');
    public $logintype = '';
    public $userid = '';
    public $layout = 'front';
    public $paginate = array('limit' => 20, 'order' => array('User.name' => 'asc'));
    public $designations = array();

    public function beforeFilter() {
        parent::beforeFilter();
        $this->logintype = $this->Session->read('logintype');
        $this->userid = $this->Session->read('user_id');
        $this->Cookie->time = 86400;

        $this->designations = array('customer' => 'JSW Head', 'zone_head' => 'Zone Head', 'area_head' => 'Area Head', 'territory_head' => 'Territory Head');
    }

    public function login() {
        if ($this->logintype != '') {
            if ($this->logintype == 'ADMIN') {
                $this->redirect(array('controller' => 'admins', 'action' => 'dashboard'));
            } else {
                $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
            }
        }
        $cookieData = $this->Cookie->read();
        $cookieUsername = isset($cookieData['cookieUsername']) ? $cookieData['cookieUsername'] : '';
        $cookiePassword = isset($cookieData['cookiePassword']) ? $cookieData['cookiePassword'] : '';
        $this->set('cookieUsername', $cookieUsername);
        $this->set('cookiePassword', $cookiePassword);
    }

    public function checklogin() {
        $this->layout = false;
        if (!empty($this->request->data)) {
            $uname = $this->request->data['User']['username'];
            $upassword = $this->request->data['User']['password'];
            $admindata = $this->User->find('first', array(
                'conditions' => array(
                    'User.name' => $uname
                )
            ));
            if (!empty($admindata)) {
                if (base64_encode($upassword) != $admindata['User']['password']) {
                    $this->Flash->error('You have entered wrong password.');
                    $this->redirect(array('controller' => 'users', 'action' => 'login'));
                }
                if ($admindata['User']['status'] == '0') {
                    $this->Flash->notice('Your account has been temporarily locked.');
                    $this->redirect(array('controller' => 'users', 'action' => 'login'));
                }
                if (isset($this->request->data['User']['rember_me'])) {
                    $this->Cookie->write('cookieUsername', $uname);
                    $this->Cookie->write('cookiePassword', $upassword);
                } else {
                    $this->Cookie->delete('cookieUsername');
                    $this->Cookie->delete('cookiePassword');
                }
                
                $accessZones = array();
                    $accessAreas = array();
                    $accessTerritory = array();

                $logintype = 'USER';
                if (strtolower($admindata['User']['designation']) == 'admin') {
                    $logintype = 'ADMIN';
                } else {
                    $designation = $admindata['User']['designation'];
                    $allow_ids = $admindata['User']['allow_ids'];

                    $this->Session->write('designation', $designation);
                    $this->Session->write('allow_ids', $admindata['User']['allow_ids']);
                    
                    if ($designation == 'territory_head') {
                        $accessTerritory = array_values(explode(',', $allow_ids));

                        $accessAreas = $this->uniqueVal($this->CommonCmp->commonList('Territory', array('territory_code' => $accessTerritory), array('area_id', 'area_id'), array('area_id' => 'ASC'), $type = 'list'));

                        $accessZones = $this->uniqueVal($this->CommonCmp->commonList('Area', array('area_code' => $accessAreas), array('zone_id', 'zone_id'), array('area_code' => 'ASC'), $type = 'list'));
                    } else if ($designation == 'area_head') {
                        
                        $accessAreas = array_values(explode(',', $allow_ids));
                        
                        $accessZones = $this->uniqueVal($this->CommonCmp->commonList('Area', array('area_code' => $accessAreas), array('zone_id', 'zone_id'), array('zone_id' => 'ASC'), $type = 'list'));

                        $accessTerritory = $this->uniqueVal($this->CommonCmp->commonList('Territory', array('area_id' => $accessAreas), array('territory_code', 'territory_code'), array('territory_code' => 'ASC'), $type = 'list'));
                    } else if ($designation == 'zone_head') {
                        $accessZones = array_values(explode(',', $allow_ids));

                        $accessAreas = $this->uniqueVal($this->CommonCmp->commonList('Area', array('zone_id' => $accessZones), array('area_id', 'area_id'), array('area_id' => 'ASC'), $type = 'list'));

                        $accessTerritory = $this->uniqueVal($this->CommonCmp->commonList('Territory', array('area_id' => $accessAreas), array('territory_code', 'territory_code'), array('territory_code' => 'ASC'), $type = 'list'));
                    }
                }
                $this->Session->write('logintype', $logintype);
                $this->Session->write('admindata', $admindata);
                $shortname = $admindata['User']['name'];
                $this->Session->write('shortname', $shortname);
                $this->Session->write('user_id', $admindata['User']['id']);               
                
                $this->Session->write('accessZones', $accessZones);
                $this->Session->write('accessAreas', $accessAreas);
                $this->Session->write('accessTerritory', $accessTerritory);
                                
                $this->Flash->success('You have logged in successfully');
                if ($logintype != 'ADMIN') {
                    $this->redirect(array('controller' => 'maps', 'action' => 'home'));
                } else {
                    $this->redirect(array('controller' => 'admins', 'action' => 'dashboard'));
                }
            } else {
                $this->Flash->error('You have entered invalid username.');
                $this->redirect('login');
            }
        } else {
            $this->Flash->warning('Please provide your login credentials.');
            $this->redirect('login');
        }
    }

    private function uniqueVal($passValues) {
        if (count($passValues) > 0) {
            $passValues = array_unique(array_values($passValues));
        }
        return $passValues;
    }

    public function dashboard() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'users', 'action' => 'login'));
        } else {
            $this->set('title_for_layout', 'BUSINESS DATA MAPPING');
            $this->redirect(array('controller' => 'maps', 'action' => 'home'));
        }
    }

    public function changepassword() {
        $this->layout = 'front';
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'users', 'action' => 'login'));
        } else {
            $this->set('title_for_layout', 'User || Change Password');
        }
    }

    public function checkpassword() {
        $this->layout = false;
        if (!empty($this->request->data)) {
            $conditions = array(
                'password' => base64_encode($this->request->data['colvalue']),
                'id' => $this->userid
            );
            $checkexist = $this->User->find('count', array(
                'conditions' => $conditions
            ));
            if ($checkexist > 0) {
                echo "MATCHED";
                die;
            } else {
                echo "NOTMATCHED";
                die;
            }
        }
    }

    public function savepassword() {
        if (!empty($this->request->data)) {
            if ($this->request->data['Admin']['newpassword'] == $this->request->data['Admin']['currentpassword']) {
                $this->Flash->error('Current Password and New Password both are same.');
                $this->redirect('changepassword');
            } else if ($this->request->data['Admin']['newpassword'] == $this->request->data['Admin']['confirmpassword']) {
                $conditions = array(
                    'password' => base64_encode($this->request->data['Admin']['currentpassword']),
                    'id' => $this->userid
                );
                $admindata = $this->User->find('first', array('conditions' => $conditions, 'fields' => array('id', 'password')));
                if (!empty($admindata)) {
                    if ($this->User->updateAll(array('password' => "'" . base64_encode($this->request->data['Admin']['newpassword']) . "'"), array('id' => $admindata['User']['id']))) {
                        $this->Flash->success('Password changed successfully.');
                        $this->redirect('changepassword');
                    } else {
                        $this->Flash->error('Please try after sometime.');
                        $this->redirect('changepassword');
                    }
                } else {
                    $this->Flash->error('Invalid Current Password.');
                    $this->redirect('changepassword');
                }
            } else {
                $this->Flash->error('New Password and Confirm Password do not matched.');
                $this->redirect('changepassword');
            }
        }
    }

    public function logout() {
        $this->Session->destroy();
        $this->Flash->notice('You have logged out successfully.');
        $this->redirect(array('controller' => 'users', 'action' => 'login'));
    }

    public function retrievepassword() {
        if (isset($this->request->data['User']['email'])) {
            $toemail = $this->request->data['User']['email'];
            $conditions = array(
                'User.email' => $toemail
            );
            $checkexist = $this->User->find('first', array(
                'conditions' => $conditions
            ));
            if (!empty($checkexist)) {

                $name = $checkexist['User']['name'];
                $password = json_decode($checkexist['User']['password']);

                $body = "Hi " . ucfirst($name) . ",<br/><br/><br/>";
                $body .= "You have requested the password for your JSW login.<br/><br/>";
                $body .= "<b>Your Username : </b>" . $name . "<br/>";
                $body .= "<b>Pssword : </b>" . $password . "<br/><br/><br/>";

                $body .= "Thankyou<br/>JSW Support Team";

                $subject = 'Forget password';

                $this->sendEmail($toemail, $subject, $body);
                $this->Flash->success('Password have been sent to your email.');
            } else {
                $this->Flash->notice('This email address is not registered with us.');
            }
        } else {
            $this->Flash->notice('Please provide email address');
        }
        $this->redirect(array('controller' => 'users', 'action' => 'login'));
    }

    public function addUser() {
        $this->layout = 'default';
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Add User');
            
            $this->set('designations', $this->designations);
            $zoneList = $this->CommonCmp->commonList('Zone', array('Zone.status' => 'true'), array('Zone.zone_code', 'Zone.zone_name_code'), array('Zone.zone_code' => 'ASC'), 'list');

            $areaList = $this->CommonCmp->commonList('Area', array('Area.status' => 'true'), array('Area.area_code', 'Area.area_name_code'), array('Area.area_code' => 'ASC'), 'list');


            $territeryList = $this->CommonCmp->commonList('Territory', array('Territory.status' => 'true'), array('Territory.territory_code', 'Territory.territory_code'), array('Territory.territory_code' => 'ASC'), 'list');

            $this->set('zoneList', $zoneList);
            $this->set('areaList', $areaList);
            $this->set('territeryList', $territeryList);
        }
    }

    public function editUser() {
        $this->layout = 'default';
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Update User');
            $this->set('designations', $this->designations);
            $rid = $this->request->query('id');
            if (!empty($rid) && ($rid != '')) {
                $this->User->id = $rid;
                $this->request->data = $this->User->read();
            } else {
                $this->redirect('manageusers');
            }
            $this->set('designations', $this->designations);
            $zoneList = $this->CommonCmp->commonList('Zone', array('Zone.status' => 'true'), array('Zone.zone_code', 'Zone.zone_name_code'), array('Zone.zone_code' => 'ASC'), 'list');

            $areaList = $this->CommonCmp->commonList('Area', array('Area.status' => 'true'), array('Area.area_code', 'Area.area_name_code'), array('Area.area_code' => 'ASC'), 'list');


            $territeryList = $this->CommonCmp->commonList('Territory', array('Territory.status' => 'true'), array('Territory.territory_code', 'Territory.territory_code'), array('Territory.territory_code' => 'ASC'), 'list');

            $this->set('zoneList', $zoneList);
            $this->set('areaList', $areaList);
            $this->set('territeryList', $territeryList);
        }
    }

    public function saveUser() {
        if (!empty($this->request->data)) {
            $conditions = array(
                'name' => $this->request->data['User']['name']
            );
            $msg = 'User added successfully.';
            if (isset($this->request->data['User']['id']) && ($this->request->data['User']['id'] != '')) {
                $conditions['id !='] = $this->request->data['User']['id'];
                $msg = 'User updated successfully.';
            }
            $checkexist = $this->User->find('count', array(
                'conditions' => $conditions
            ));
            if ($checkexist <= 0) {
                $designation = $this->request->data['User']['designation'];
                $selectedIds = $this->request->data['User'][$designation];
                
                if (isset($this->request->data['User']['zone_head'])) {
                    unset($this->request->data['User']['zone_head']);
                }
                if (isset($this->request->data['User']['area_head'])) {
                    unset($this->request->data['User']['area_head']);
                }
                if (isset($this->request->data['User']['territory_head'])) {
                    unset($this->request->data['User']['territory_head']);
                }
                $this->request->data['User'][$designation] = $selectedIds;
                
                if (isset($this->request->data['User']['password'])) {
                    $this->request->data['User']['password'] = base64_encode($this->request->data['User']['password']);
                }
                if (isset($this->request->data['User'][$designation])) {
                    unset($this->request->data['User'][$designation]);
                }
                if (isset($selectedIds) && $selectedIds != '') {
                    if(count($selectedIds)>1){
                        $this->request->data['User']['allow_ids'] = implode(',', $selectedIds);
                    }
                    else{
                        $this->request->data['User']['allow_ids'] = $selectedIds;
                    }    
                }
                $this->User->create();
                if ($this->User->save($this->request->data)) {
                    $this->Flash->success('User added successfully.');
                    $this->redirect('manageusers');
                } else {
                    $this->Flash->warning('Please fill all fields.');
                    $this->redirect('manageusers');
                }
            } else {
                $this->Flash->warning('Username already exists.');
                $this->redirect('manageusers');
            }
        }
    }

    public function manageusers() {
        $this->layout = 'default';
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Manage User');
            $conditions = array('designation !=' => 'admin');
            $searchkey = '';
            if (isset($this->request->data['User']['searchkey']) && ($this->request->data['User']['searchkey'] != '')) {
                $searchkey = $this->request->data['User']['searchkey'];
                $conditions['OR'] = array(
                    'User.name LIKE' => "%$searchkey%"
                );
            }
            $this->paginate['conditions'] = $conditions;
            $this->set('searchkey', $searchkey);

            $this->Paginator->settings = $this->paginate;
            $data = $this->Paginator->paginate('User');
            $this->set('data', $data);
            $this->set('designationList', $this->designations);
        }
    }

    public function groupaction() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $querydata = $this->request->query;
            $statusArr = $this->CommonCmp->groupActions('User', $querydata);
            $status = isset($statusArr['status']) ? $statusArr['status'] : 'error';
            $msg = isset($statusArr['msg']) ? $statusArr['msg'] : 'Technical error please try after sometime.';
            $this->Flash->$status($msg);
            $this->redirect($this->referer());
        }
    }

}
