<?php

App::import('AppController', 'Controller');

class ZonesController extends AppController {

    public $name = 'Zones';
    public $uses = array('Zone', 'Country', 'Area');
    public $helper = array('Html', 'Session', 'Paginator');
    public $components = array('Session', 'Paginator', 'Flash', 'CommonCmp');
    public $paginate = array('limit' => 20, 'order' => array('Zone.zone_name' => 'asc'));
    public $user_id = '';
    public $logintype = '';

    public function beforeFilter() {
        parent::beforeFilter();
        $this->logintype = $this->Session->read('logintype');
    }

    public function managezones() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Manage Zone');
            $conditions = array();
            $searchkey = '';
            if (isset($this->request->data['Zone']['searchkey']) && ($this->request->data['Zone']['searchkey'] != '')) {
                $searchkey = trim($this->request->data['Zone']['searchkey']);
                $conditions['OR'] = array(
                    'Zone.zone_code LIKE' => "%$searchkey%",
                    'Zone.zone_name LIKE' => "%$searchkey%"
                );
            }

            $this->paginate['conditions'] = $conditions;
            $this->set('searchkey', $searchkey);

            $this->Paginator->settings = $this->paginate;
            $data = $this->Paginator->paginate('Zone');
            $this->set('data', $data);
        }
    }

    public function addZone() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Add Zone');
        }
    }

    public function editZone() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $this->set('title_for_layout', 'Administrator || Update Zone');
            $rid = $this->request->query('id');
            if (!empty($rid) && ($rid != '')) {
                $this->Zone->id = $rid;
                $this->request->data = $this->Zone->read();
            } else {
                $this->redirect('managezones');
            }
        }
    }

    public function saveZone() {

        if (!empty($this->request->data)) {
            $conditions = array(
                'zone_code' => $this->request->data['Zone']['zone_code']
            );
            $msg = 'Zone added successfully.';
            if (isset($this->request->data['Zone']['id']) && ($this->request->data['Zone']['id'] != '')) {
                $conditions['id !='] = $this->request->data['Zone']['id'];
                $msg = 'Zone updated successfully.';
            }
            $checkexist = $this->Zone->find('count', array(
                'conditions' => $conditions
            ));
            if ($checkexist <= 0) {
                $this->Zone->create();
                $zid = $this->request->data['Zone']['id'];
                $zoneCode = $this->Zone->find('list', array('fields' => 'Zone.zone_code', 'conditions' => array('Zone.id' => $zid)));
                if ($this->Zone->save($this->request->data)) {
                    $this->Flash->success('Zone added successfully.');
                    $this->redirect('managezones');
                } else {
                    $this->Flash->warning('Please fill all fields.');
                    $this->redirect('managezones');
                }
            } else {
                $this->Flash->warning('Zone already exists.');
                $this->redirect('managezones');
            }
        }
    }

    public function groupaction() {
        if ($this->logintype == '') {
            $this->Flash->warning(NOT_LOGGEDIN_MSG);
            $this->redirect(array('controller' => 'admins', 'action' => 'login'));
        } else if ($this->logintype != 'ADMIN') {
            $this->Flash->warning(PERMISSION_DENIDE);
            $this->redirect(array('controller' => 'users', 'action' => 'dashboard'));
        } else {
            $querydata = $this->request->query;
            $statusArr = $this->CommonCmp->groupActions('Zone', $querydata);
            $status = isset($statusArr['status']) ? $statusArr['status'] : 'error';
            $msg = isset($statusArr['msg']) ? $statusArr['msg'] : 'Technical error please try after sometime.';
            $this->Flash->$status($msg);
            $this->redirect($this->referer());
        }
    }

}
