<?php

/*
 * Author      : Compare Infobase Dev Team
 * Created on  : 19-12-2018 10:10 AM 
 * Modified on : 19-12-2018 10:10 AM
 * Objective   : Dealer controler class written for the dealers related Apis
 */

class DealersController extends ApisAppController {

    public $name = 'Dealers';
    public $uses = array('Dealer');
    public $components = array('Email', 'ValidationCmp', 'Paginator');
    public $paginate = array('limit' => 20, 'order' => array('Dealer.company_name' => 'asc'));

    public function beforeFilter() {
        parent::beforeFilter();
        $this->layout = false;
        $this->autoRender = false;
    }

    public function beforeRender() {
        parent::beforeRender();
        $this->autoRender = false;
    }

    public function dealerdetails() {
        $reponsestatus = array();
        $dataFull = $this->request->query;
        $invalidFields = $this->ValidationCmp->validateParams(array('dealerId'), $dataFull);
        if (!$this->ValidationCmp->allowMethod($this->request, 'get')) {
            $reponsestatus = $this->ValidationCmp->statusCode(405, $this->_statusCodes);
        } else if (count($invalidFields) > 0) {
            $reponsestatus = $this->ValidationCmp->missingParameter(700, $invalidFields);
        } else if (!$this->ValidationCmp->isValidNumber($dataFull['dealerId'])) {
            $reponsestatus = $this->ValidationCmp->statusCode(800, $this->_statusCodes);
        } else {
            try {
                $dealerdata = $this->Dealer->findById($dataFull['dealerId']);
                if (!empty($dealerdata)) {
                    $dealerdata = current($dealerdata);
                    $reponsestatus = array(
                        'errorStatus' => 'false',
                        'statusCode' => 200,
                        'msg' => 'Dealer details',
                        'detailData' => $dealerdata
                    );
                } else {
                    $reponsestatus = $this->ValidationCmp->statusCode(900, $this->_statusCodes);
                }
            } catch (Exception $e) {
                $reponsestatus = $this->ValidationCmp->statusCode(500, $this->_statusCodes);
            }
        }
        echo $this->ValidationCmp->outputJson($reponsestatus);
    }

    public function dealerlist() {
        $reponsestatus = array();
        $dataFull = $this->request->query;
        $invalidFields = $this->ValidationCmp->validateParams(array('pageNo'), $dataFull);
        if (!$this->ValidationCmp->allowMethod($this->request, 'get')) {
            $reponsestatus = $this->ValidationCmp->statusCode(405, $this->_statusCodes);
        } else if (count($invalidFields) > 0) {
            $reponsestatus = $this->ValidationCmp->missingParameter(700, $invalidFields);
        } else {
            try {
                $conditions = array();
                $searchkey = '';
                if (isset($dataFull['searchKey']) && ($dataFull['searchKey'] != '')) {
                    $searchkey = urldecode($dataFull['searchKey']);
                    $conditions['OR'] = array(
                        'Dealer.sap_id LIKE' => "%$searchkey%",
                        'Dealer.company_name LIKE' => "%$searchkey%",
                        'Dealer.contact_name LIKE' => "%$searchkey%",
                        'Dealer.dealer_latlong LIKE' => "%$searchkey%",
                        'Dealer.phone_mobile LIKE' => "%$searchkey%"
                    );
                }

                $page = isset($dataFull['pageNo']) ? $dataFull['pageNo'] : 1;
                $this->paginate['page'] = $page;
                $this->paginate['conditions'] = $conditions;
                $this->set('searchkey', $searchkey);
                $this->Paginator->settings = $this->paginate;
                $data = $this->Paginator->paginate('Dealer');
                $pagingData = isset($this->request->params['paging']['Dealer']) ? $this->request->params['paging']['Dealer'] : array();
                $itemsPerPage = isset($this->Paginator->settings['limit']) ? $this->Paginator->settings['limit'] : 10;
                $totalItems = isset($pagingData['count']) ? $pagingData['count'] : 0;
                $prevPage = $page - 1;
                $totalPages = isset($pagingData['pageCount']) ? $pagingData['pageCount'] : 1;
                $dataArr = $this->ValidationCmp->processData($data);
                $reponsestatus = array(
                    'errorStatus' => 'false',
                    'statusCode' => 200,
                    'msg' => 'Dealer list',
                    'totalItems' => $totalItems,
                    'currentPage' => (int) $page,
                    'prevPage' => $prevPage,
                    'totalPages' => $totalPages,
                    'listData' => $dataArr
                );
            } catch (Exception $e) {
                $reponsestatus = $this->ValidationCmp->statusCode(500, $this->_statusCodes);
            }
        }
        echo $this->ValidationCmp->outputJson($reponsestatus);
    }

    public function dealeradd() {
        $reponsestatus = array();
        $dataFull = $this->request->query;
        $invalidFields = $this->ValidationCmp->validateParams(array('pageNo'), $dataFull);
        if (!$this->ValidationCmp->allowMethod($this->request, 'get')) {
            $reponsestatus = $this->ValidationCmp->statusCode(405, $this->_statusCodes);
        } else if (count($invalidFields) > 0) {
            $reponsestatus = $this->ValidationCmp->missingParameter(700, $invalidFields);
        } else {
            try {
                $conditions = array();
                $searchkey = '';

                /* $companyName = $this->ValidationCmp->validateParameterValue('numeric','companyName', $dataFull);
                  $contactName = isset($dataFull['contactName'] ?  $dataFull['contactName'] : '';
                  $latLong = isset($dataFull['latLong'] ?  $dataFull['latLong'] : '';
                  $stateCode = isset($dataFull['stateCode'] ?  $dataFull['stateCode'] : '';
                  $spokeId = isset($dataFull['spokeId'] ?  $dataFull['spokeId'] : '';
                  $cityCode = isset($dataFull['cityCode'] ?  $dataFull['cityCode'] : '';
                  $mobileNo = isset($dataFull['mobileNo'] ?  $dataFull['mobileNo'] : '';
                  $landlineNo = isset($dataFull['landlineNo'] ?  $dataFull['landlineNo'] : '';
                  $pincodeId = isset($dataFull['pincodeId'] ?  $dataFull['pincodeId'] : '';
                  $loyaltyStatus = isset($dataFull['loyaltyStatus'] ?  $dataFull['loyaltyStatus'] : '';
                  $expMboStatus = isset($dataFull['expMboStatus'] ?  $dataFull['expMboStatus'] : '';
                  $sapId = isset($dataFull['sapId'] ?  $dataFull['sapId'] : '';
                  $houseNo = isset($dataFull['houseNo'] ?  $dataFull['houseNo'] : '';
                  $street1 = isset($dataFull['street1'] ?  $dataFull['street1'] : '';
                  $street2 = isset($dataFull['street2'] ?  $dataFull['street2'] : '';
                  $street3 = isset($dataFull['street3'] ?  $dataFull['street3'] : '';
                  $street4 = isset($dataFull['street4'] ?  $dataFull['street4'] : '';
                  $district = isset($dataFull['district'] ?  $dataFull['district'] : '';
                  $postalCode = isset($dataFull['postalCode'] ?  $dataFull['postalCode'] : '';
                  $city = isset($dataFull['city'] ?  $dataFull['city'] : '';
                  $region = isset($dataFull['region'] ?  $dataFull['region'] : '';
                  $country = isset($dataFull['country'] ?  $dataFull['country'] : ''; */



//id, company_name, contact_name, dealer_latlong, state_code, spoke_id, city_code, phone_mobile, phone_landline, pincode_id, loyalty_status, created_at, updated_at, status, exp_mbo_status, sap_id, house_no, street1, street2, street3, street4, district, postal_code, city, region, country
//id, company_name, contact_name, dealer_latlong, state_code, spoke_id, city_code, phone_mobile, phone_landline, pincode_id, loyalty_status, created_at, updated_at, status, exp_mbo_status, sap_id, house_no, street1, street2, street3, street4, district, postal_code, city, region, country

                $paramsArr = array('companyName' => 'text', 'contactName' =>'text', 'latLong'=>'LatLong', 'stateCode'=>'code', 'spokeId'=>'Numeric', 'cityCode'=>'code', 'mobileNo'=>'Mobile', 'landlineNo'=>'Numeric', 'pincodeId'=>'Pincode', 'loyaltyStatus'=>'text', 'expMboStatus'=>'', 'sapId', 'houseNo', 'street1', 'street2', 'street3', 'street4', 'district', 'postalCode', 'city', 'region', 'country');

                foreach ($paramsArr as $p) {
                    $this->ValidationCmp->cleanInputValue($key, $dataFull, $type);
                }

                $reponsestatus = array(
                    'errorStatus' => 'false',
                    'statusCode' => 200,
                    'msg' => 'Dealer list',
                    'totalItems' => $totalItems,
                    'currentPage' => (int) $page,
                    'prevPage' => $prevPage,
                    'totalPages' => $totalPages,
                    'listData' => $dataArr
                );
            } catch (Exception $e) {
                $reponsestatus = $this->ValidationCmp->statusCode(500, $this->_statusCodes);
            }
        }
        echo $this->ValidationCmp->outputJson($reponsestatus);
    }
}
