<?php

/*
 * Author      : Compare Infobase Dev Team
 * Created on  : 21-12-2018 10:10 AM 
 * Modified on : 21-12-2018 10:10 AM
 * Objective   : Pincodes controler class written for the pincodes related Apis
 */

class PincodesController extends ApisAppController {

    public $name = 'Pincodes';
    public $uses = array('Pincode');
    public $components = array('ValidationCmp', 'Paginator');
    public $paginate = array('limit' => 20, 'order' => array('Pincode.pincode' => 'asc'));

    public function beforeFilter() {
        parent::beforeFilter();
        $this->layout = false;
        $this->autoRender = false;
    }

    public function beforeRender() {
        parent::beforeRender();
        $this->autoRender = false;
    }

    public function pincodedetails() {
        $reponsestatus = array();
        $dataFull = $this->request->query;
        $invalidFields = $this->ValidationCmp->validateParams(array('pincodeId'), $dataFull);
        if (!$this->ValidationCmp->allowMethod($this->request, 'get')) {
            $reponsestatus = $this->ValidationCmp->statusCode(405, $this->_statusCodes);
        } else if (count($invalidFields) > 0) {
            $reponsestatus = $this->ValidationCmp->missingParameter(700, $invalidFields);
        } else if (!$this->ValidationCmp->isValidNumber($dataFull['pincodeId'])) {
            $reponsestatus = $this->ValidationCmp->statusCode(800, $this->_statusCodes);
        } else {
            try {
                $pincodedata = $this->Pincode->findById($dataFull['pincodeId']);
                if (!empty($pincodedata)) {
                    $pincodedata = current($pincodedata);
                    $reponsestatus = array(
                        'errorStatus' => 'false',
                        'statusCode' => 200,
                        'msg' => 'Pincode details',
                        'detailData' => $pincodedata
                    );
                } else {
                    $reponsestatus = $this->ValidationCmp->statusCode(900, $this->_statusCodes);
                }
            } catch (Exception $e) {
                $reponsestatus = $this->ValidationCmp->statusCode(500, $this->_statusCodes);
            }
        }
        echo $this->ValidationCmp->outputJson($reponsestatus);
    }

    public function pincodelist() {
        $reponsestatus = array();
        $dataFull = $this->request->query;
        $invalidFields = $this->ValidationCmp->validateParams(array('pageNo'), $dataFull);
        if (!$this->ValidationCmp->allowMethod($this->request, 'get')) {
            $reponsestatus = $this->ValidationCmp->statusCode(405, $this->_statusCodes);
        } else if (count($invalidFields) > 0) {
            $reponsestatus = $this->ValidationCmp->missingParameter(700, $invalidFields);
        } else {
            try {
                $conditions = array();
                $searchkey = '';
                if (isset($dataFull['searchKey']) && ($dataFull['searchKey'] != '')) {
                    $searchkey = urldecode($dataFull['searchKey']);
                    $conditions['OR'] = array(
                        'Pincode.pincode LIKE' => "%$searchkey%",
                        'Pincode.territory_id LIKE' => "%$searchkey%"
                    );
                }

                $page = isset($dataFull['pageNo']) ? $dataFull['pageNo'] : 1;
                $this->paginate['page'] = $page;
                $this->paginate['conditions'] = $conditions;
                $this->set('searchkey', $searchkey);
                $this->Paginator->settings = $this->paginate;
                $data = $this->Paginator->paginate('Pincode');
                $pagingData = isset($this->request->params['paging']['Pincode']) ? $this->request->params['paging']['Pincode'] : array();
                $itemsPerPage = isset($this->Paginator->settings['limit']) ? $this->Paginator->settings['limit'] : 10;
                $totalItems = isset($pagingData['count']) ? $pagingData['count'] : 0;
                $prevPage = $page - 1;
                $totalPages = isset($pagingData['pageCount']) ? $pagingData['pageCount'] : 1;
                $dataArr = $this->ValidationCmp->processData($data);
                $reponsestatus = array(
                    'errorStatus' => 'false',
                    'statusCode' => 200,
                    'msg' => 'Pincode list',
                    'totalItems' => $totalItems,
                    'currentPage' => (int) $page,
                    'prevPage' => $prevPage,
                    'totalPages' => $totalPages,
                    'listData' => $dataArr
                );
            } catch (Exception $e) {
                $reponsestatus = $this->ValidationCmp->statusCode(500, $this->_statusCodes);
            }
        }
        echo $this->ValidationCmp->outputJson($reponsestatus);
    }

    public function pincodeadd() {
        $reponsestatus = array();
        $dataFull = $this->request->query;
        $invalidFields = $this->ValidationCmp->validateParams(array('pageNo'), $dataFull);
        if (!$this->ValidationCmp->allowMethod($this->request, 'get')) {
            $reponsestatus = $this->ValidationCmp->statusCode(405, $this->_statusCodes);
        } else if (count($invalidFields) > 0) {
            $reponsestatus = $this->ValidationCmp->missingParameter(700, $invalidFields);
        } else {
            try {
                $conditions = array();
                $searchkey = '';

                $paramsArr = array('companyName' => 'text', 'contactName' =>'text', 'latLong'=>'LatLong', 'stateCode'=>'code', 'spokeId'=>'Numeric', 'cityCode'=>'code', 'mobileNo'=>'Mobile', 'landlineNo'=>'Numeric', 'pincodeId'=>'Pincode', 'loyaltyStatus'=>'text', 'expMboStatus'=>'', 'sapId', 'houseNo', 'street1', 'street2', 'street3', 'street4', 'district', 'postalCode', 'city', 'region', 'country');

                foreach ($paramsArr as $p) {
                    $this->ValidationCmp->cleanInputValue($key, $dataFull, $type);
                }

                $reponsestatus = array(
                    'errorStatus' => 'false',
                    'statusCode' => 200,
                    'msg' => 'Pincode list',
                    'totalItems' => $totalItems,
                    'currentPage' => (int) $page,
                    'prevPage' => $prevPage,
                    'totalPages' => $totalPages,
                    'listData' => $dataArr
                );
            } catch (Exception $e) {
                $reponsestatus = $this->ValidationCmp->statusCode(500, $this->_statusCodes);
            }
        }
        echo $this->ValidationCmp->outputJson($reponsestatus);
    }
}